from setuptools import setup
 
setup(
    name='t-b-sh',    # This is the name of your PyPI-package.
    version='0.1.2',                          # Update the version number for new releases
    scripts=['t-b-sh'],                  # The name of your scipt, and also the command you'll be using for calling it    
    author="Sriharsha Sammeta",
    author_email="sriharsha4444@icloud.com",
    install_requires=[
   'python>=3.6'
    ]
)
